====================
atsphinx-audioplayer
====================

Register directive to render audio element

Getting started
===============

.. code:: console

   pip install atsphinx-audioplayer

Usage
=====

Write ``audio`` directive into your document.

.. code:: rst

   .. audio:: talk.mp3

You can write as role too.

.. code:: rst

   :audio:`talk.mp3`
